result_source_hash

Function result_source_hash 

pub fn result_source_hash(parent: &OutlineNode) -> Option<&str>
Read the source-hash:: recorded in the result subblock under parent, if any. Returns None when no result subblock exists or when it was written without the hash (pre-auto-run runs).